===============================
ejpiaj
===============================

.. image:: https://badge.fury.io/py/ejpiaj.png
    :target: http://badge.fury.io/py/ejpiaj
    
.. image:: https://travis-ci.org/onjin/ejpiaj.png?branch=master
        :target: https://travis-ci.org/onjin/ejpiaj

.. image:: https://pypip.in/d/ejpiaj/badge.png
        :target: https://crate.io/packages/ejpiaj?version=latest


License
-------

* Free software: BSD license

Features
--------

Test remote API with simple yaml files

Documentation
-------------
* http://ejpiaj.readthedocs.org/en/latest/
